@@ -83,7 +83,10 @@ struct _SeahorseContextClass {
     void (*removed) (SeahorseContext *sctx, struct _SeahorseObject *sobj);
     
     /* This object has changed */
-    void (*changed) (SeahorseContext *sctx, struct _SeahorseObject *sobj, int change);
+    void (*changed) (SeahorseContext *sctx, struct _SeahorseObject *sobj);
+    
+    /* The source is being refreshed */
+    void (*refreshing) (SeahorseContext *sctx, SeahorseOperation *op);
 };
 
 enum SeahorseContextType {
@@ -91,6 +94,8 @@ enum SeahorseContextType {
     SEAHORSE_CONTEXT_DAEMON = 2,
 };
 
+typedef void (*SeahorseObjectFunc) (struct _SeahorseObject *obj, gpointer user_data);
+
 #define             SCTX_APP()                          (seahorse_context_for_app ())
 
 GType               seahorse_context_get_type           (void);
@@ -148,26 +153,29 @@ GList*              seahorse_context_find_objects       (SeahorseContext    *sct
                                                          SeahorseUsage      usage,
                                                          SeahorseLocation   location);
 
-GList*              seahorse_context_find_objects_full  (SeahorseContext *sctx,
+GList*              seahorse_context_find_objects_full  (SeahorseContext *self,
                                                          struct _SeahorseObjectPredicate *skpred);
-                                                         
-void                seahorse_context_remove_object      (SeahorseContext *sctx,
-                                                         struct _SeahorseObject *sobj);
 
-gboolean            seahorse_context_owns_object        (SeahorseContext *sctx,
+void                seahorse_context_for_objects_full   (SeahorseContext *self,
+                                                         struct _SeahorseObjectPredicate *skpred,
+                                                         SeahorseObjectFunc func,
+                                                         gpointer user_data);
+
+void                seahorse_context_verify_objects     (SeahorseContext *self);
+
+void                seahorse_context_remove_object      (SeahorseContext *sctx,
                                                          struct _SeahorseObject *sobj);
 
 SeahorseServiceDiscovery*
                     seahorse_context_get_discovery      (SeahorseContext    *sctx);
 
-struct _SeahorseKey*   seahorse_context_get_default_key (SeahorseContext    *sctx);
+struct _SeahorseObject*   
+                    seahorse_context_get_default_key    (SeahorseContext    *sctx);
 
-SeahorseOperation*  seahorse_context_refresh_local         (SeahorseContext    *sctx);
+void                seahorse_context_refresh_auto       (SeahorseContext *sctx);
 
-void                seahorse_context_refresh_local_async   (SeahorseContext *sctx);
-
-SeahorseOperation*  seahorse_context_search_remote         (SeahorseContext    *sctx,
-                                                            const gchar        *search);
+SeahorseOperation*  seahorse_context_search_remote      (SeahorseContext    *sctx,
+                                                         const gchar        *search);
 
 SeahorseOperation*  seahorse_context_transfer_objects   (SeahorseContext    *sctx, 
                                                          GList              *objs, 
@@ -183,15 +191,17 @@ GList*              seahorse_context_discover_objects   (SeahorseContext    *sct
                                                          GSList             *ids);
 
 struct _SeahorseObject*     seahorse_context_object_from_dbus   (SeahorseContext    *sctx,
-                                                         const gchar        *dbusid,
-                                                         guint              *uid);
+                                                         const gchar        *dbusid);
 
 gchar*              seahorse_context_object_to_dbus     (SeahorseContext    *sctx,
-                                                         struct _SeahorseObject *sobj,
-                                                         guint              uid);
+                                                         struct _SeahorseObject *sobj);
 
 gchar*              seahorse_context_id_to_dbus         (SeahorseContext    *sctx,
-                                                         GQuark             id, 
-                                                         guint              uid);
+                                                         GQuark             id);
+
+
+typedef GQuark (*SeahorseCanonizeFunc) (const gchar *id);
+
+GQuark              seahorse_context_canonize_id        (GQuark ktype, const gchar *id);
 
 #endif /* __SEAHORSE_CONTEXT_H__ */
