@@ -298,7 +298,8 @@ seahorse_widget_new (const gchar *name, GtkWindow *parent)
 
     /* We don't care about this floating business */
     g_object_ref (GTK_OBJECT (swidget));
-    gtk_object_sink (GTK_OBJECT (swidget));
+    g_object_ref_sink (GTK_OBJECT (swidget));
+    g_object_unref (GTK_OBJECT (swidget));
 
     return swidget;
 }
@@ -325,7 +326,8 @@ seahorse_widget_new_allow_multiple (const gchar *name, GtkWindow *parent)
     
     /* We don't care about this floating business */
     g_object_ref (GTK_OBJECT (swidget));
-    gtk_object_sink (GTK_OBJECT (swidget));
+    g_object_ref_sink (GTK_OBJECT (swidget));
+    g_object_unref (GTK_OBJECT (swidget));
 
     return swidget;
 }
